@@ -5,7 +5,7 @@
  * This function tell other modules what users have access
  * to the plugin.
  *
- * @version $Id: auth.php 10633 2006-02-03 22:27:56Z jervfors $
+ * @version $Id: auth.php 12538 2007-07-14 19:04:00Z kink $
  * @author Philippe Mingo
  * @copyright (c) 1999-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -19,7 +19,7 @@
  * @return boolean
  */
 function adm_check_user() {
-    global $PHP_SELF, $plugins;
+    global $plugins;
     require_once(SM_PATH . 'functions/global.php');
     
     if ( !in_array('administrator', $plugins) ) {
@@ -31,7 +31,7 @@ function adm_check_user() {
     }
 
     /* This needs to be first, for all non_options pages */
-    if (strpos('options.php', $PHP_SELF)) {
+    if (defined('PAGE_NAME') && PAGE_NAME=='administrator_options') {
         $auth = FALSE;
     } else if (file_exists(SM_PATH . 'plugins/administrator/admins')) {
         $auths = file(SM_PATH . 'plugins/administrator/admins');
@@ -62,4 +62,3 @@ function adm_check_user() {
 function adm_array_trim(&$value,$key) {
     $value=trim($value);
 }
-?>
\ No newline at end of file
